import type { TokenValueFunction } from '@/lib/util';
/**
 * Represents cookie options in config
 */
export declare class CookieOptions {
    domain: string;
    httpOnly: boolean;
    maxAge: number | undefined;
    name: string;
    path: string;
    sameSite: boolean | 'none' | 'strict' | 'lax';
    secure: boolean;
    constructor(opts?: Partial<CookieOptions>);
}
/**
 * Represents token options in config
 */
export declare class TokenOptions {
    value: TokenValueFunction | undefined;
    constructor(opts?: Partial<TokenOptions>);
}
/**
 * Represents CsrfProtect configuration object
 */
export declare class Config {
    excludePathPrefixes: string[];
    ignoreMethods: string[];
    saltByteLength: number;
    secretByteLength: number;
    cookie: CookieOptions;
    token: TokenOptions;
    constructor(opts?: Partial<ConfigOptions>);
}
/**
 * Represents CsrfProtect configuration options object
 */
export interface ConfigOptions extends Omit<Config, 'cookie' | 'token'> {
    cookie: Partial<CookieOptions>;
    token: Partial<TokenOptions>;
}
/**
 * Represents a cookie
 */
export type Cookie = CookieOptions & {
    value: string;
};
/**
 * Represents arguments for CsrfProtectionFunction
 */
export type CsrfProtectArgs = {
    request: Request;
    url: {
        pathname: string;
    };
    getCookie: (name: string) => string | undefined;
    setCookie: (cookie: Cookie) => void;
};
/**
 * Represents signature of CSRF protect function
 */
export type CsrfProtect = {
    (args: CsrfProtectArgs): Promise<string | undefined>;
};
/**
 * Create CSRF protection function
 * @param {Partial<ConfigOptions>} opts - Configuration options
 * @returns {CsrfProtectFunction} - The CSRF protect function
 * @throws {CsrfError} - An error if CSRF validation failed
 */
export declare function createCsrfProtect(opts?: Partial<ConfigOptions>): CsrfProtect;
