export type TokenValueFunction = {
    (request: Request): Promise<string>;
};
/**
 * Create new secret (cryptographically secure)
 * @param {int} length - Byte length of secret
 */
export declare function createSecret(length: number): Uint8Array;
/**
 * Encode Uint8Array as base64 string
 * @param {Uint8Array} input - The data to be converted from Uint8Array to base64
 */
export declare function utoa(input: Uint8Array): string;
/**
 * Decode base64 string into Uint8Array
 * @param {string} input - The data to be converted from base64 to Uint8Array
 */
export declare function atou(inputB64: string): Uint8Array;
/**
 * Get CSRF token from request
 * @param {Request} request - The request object
 * @param {ValueFunc|null} valueFn - Function to retrieve token value from request
 */
export declare function getTokenString(request: Request, valueFn?: TokenValueFunction): Promise<string>;
/**
 * Create new salt
 * @param {int} length - Salt length in number of bytes
 */
export declare function _createSalt(byteLength: number): Uint8Array;
/**
 * Calculate hash of secret and salt
 * @param {Uint8Array} secret - The secret
 * @param {Uint8Array} salt - The salt
 */
export declare function _hash(secret: Uint8Array, salt: Uint8Array): Promise<Uint8Array>;
/**
 * Create new CSRF token (cryptographically insecure salt hashed with secret)
 * @param {Uint8Array} secret - The secret
 * @param {int} saltByteLength - Salt length in number of bytes
 */
export declare function createToken(secret: Uint8Array, saltByteLength: number): Promise<Uint8Array>;
/**
 * Verify CSRF token
 * @param {Uint8Array} token - The CSRF token
 * @param {Uint8Array} secret - The CSRF secret
 */
export declare function verifyToken(token: Uint8Array, secret: Uint8Array): Promise<boolean>;
