import type { NextRequest } from 'next/server';
import { NextResponse } from 'next/server';
import { Config, TokenOptions } from '@/lib/protect';
import type { ConfigOptions } from '@/lib/protect';
/**
 * Represents token options in config
 */
export declare class NextTokenOptions extends TokenOptions {
    responseHeader: string;
    constructor(opts?: Partial<NextTokenOptions>);
}
/**
 * Represents configuration object
 */
export declare class NextConfig extends Config {
    excludePathPrefixes: string[];
    token: NextTokenOptions;
    constructor(opts?: Partial<NextConfigOptions>);
}
/**
 * Represents configuration options object
 */
export interface NextConfigOptions extends Omit<ConfigOptions, 'token'> {
    token: Partial<NextTokenOptions>;
}
/**
 * Represents signature of CSRF protect function to be used in Next.js middleware
 */
export type NextCsrfProtect = {
    (request: NextRequest, response: NextResponse): Promise<void>;
};
/**
 * Create CSRF protection function for use in Next.js middleware
 * @param {Partial<NextConfigOptions>} opts - Configuration options
 * @returns {NextCsrfProtectFunction} - The CSRF protect function
 * @throws {CsrfError} - An error if CSRF validation failed
 */
export declare function createCsrfProtect(opts?: Partial<NextConfigOptions>): NextCsrfProtect;
/**
 * Create Next.js middleware function
 * @param {Partial<NextConfigOptions>} opts - Configuration options
 * @returns Next Middleware function
 */
export declare function createMiddleware(opts?: Partial<NextConfigOptions>): (request: NextRequest) => Promise<NextResponse<unknown>>;
