import type { Handle, RequestEvent, Cookies } from '@sveltejs/kit';
import { Config, TokenOptions } from '@/lib/protect';
import type { ConfigOptions } from '@/lib/protect';
export type SveltekitTokenOptions = TokenOptions;
export type SveltekitConfig = Config;
export type SveltekitConfigOptions = ConfigOptions;
/**
 * Represents locals added to Svelte by Edge-CSRF
 */
export interface EdgeCsrfLocals {
    csrfToken?: string;
}
/**
 * Represents partial request event used by SvelteKitCsrfProtect
 */
export interface SvelteKitCsrfProtectRequestEvent extends Pick<RequestEvent, 'request' | 'url' | 'locals'> {
    cookies: Pick<Cookies, 'get' | 'set'>;
}
/**
 * Represents signature of CSRF protect function to be used in SvelteKit handle
 */
export type SveltekitCsrfProtect = {
    (event: SvelteKitCsrfProtectRequestEvent): Promise<void>;
};
/**
 * Create CSRF protection function for use in a SvelteKit handle
 * @param {Partial<SveltekitConfigOptions>} opts - Configuration options
 * @returns {SveltekitCsrfProtectFunction} - The CSRF protect function
 * @throws {CsrfError} - An error if CSRF validation failed
 */
export declare function createCsrfProtect(opts?: Partial<SveltekitConfigOptions>): SveltekitCsrfProtect;
/**
 * Create SvelteKit handle
 * @param {Partial<SveltekitConfigOptions>} opts - Configuration options
 * @returns {Handle} The SvelteKit handle
 */
export declare function createHandle(opts?: Partial<SveltekitConfigOptions>): Handle;
